@@ -34,7 +34,6 @@ The library has special public value for nonexistent or expired keys called
     from oslo_cache import core
     NO_VALUE = core.NO_VALUE
 """
-import re
 import socket
 import ssl
 import urllib.parse
@@ -45,6 +44,7 @@ from dogpile.cache import proxy
 from dogpile.cache import util
 from oslo_log import log
 from oslo_utils import importutils
+from oslo_utils import netutils
 
 from oslo_cache._i18n import _
 from oslo_cache import _opts
@@ -104,15 +104,10 @@ class _DebugProxy(proxy.ProxyBackend):
 
 
 def _parse_sentinel(sentinel):
-    # IPv6 (eg. [::1]:6379 )
-    match = re.search(r'^\[(\S+)\]:(\d+)$', sentinel)
-    if match:
-        return (match[1], int(match[2]))
-    # IPv4 or hostname (eg. 127.0.0.1:6379 or localhost:6379)
-    match = re.search(r'^(\S+):(\d+)$', sentinel)
-    if match:
-        return (match[1], int(match[2]))
-    raise exception.ConfigurationError('Malformed sentinel server format')
+    host, port = netutils.parse_host_port(sentinel)
+    if host is None or port is None:
+        raise exception.ConfigurationError('Malformed sentinel server format')
+    return (host, port)
 
 
 def _build_cache_config(conf):
@@ -157,12 +152,12 @@ def _build_cache_config(conf):
             netloc = conf.cache.redis_server
         else:
             if conf.cache.redis_username:
-                netloc = '%s:%s@%s' % (conf.cache.redis_username,
-                                       conf.cache.redis_password,
-                                       conf.cache.redis_server)
+                netloc = '{}:{}@{}'.format(conf.cache.redis_username,
+                                           conf.cache.redis_password,
+                                           conf.cache.redis_server)
             else:
-                netloc = ':%s@%s' % (conf.cache.redis_password,
-                                     conf.cache.redis_server)
+                netloc = ':{}@{}'.format(conf.cache.redis_password,
+                                         conf.cache.redis_server)
 
         parts = urllib.parse.ParseResult(
             scheme=('rediss' if conf.cache.tls_enabled else 'redis'),
@@ -219,6 +214,26 @@ def _build_cache_config(conf):
             value = getattr(conf.cache, 'memcache_' + arg)
             conf_dict[f'{prefix}.arguments.{arg}'] = value
 
+    if conf.cache.backend_expiration_time is not None:
+        if conf.cache.expiration_time > conf.cache.backend_expiration_time:
+            raise exception.ConfigurationError(
+                "backend_expiration_time should not be smaller than "
+                "expiration_time.")
+        if conf.cache.backend in ('dogpile.cache.pymemcache',
+                                  'dogpile.cache.memcached',
+                                  'dogpile.cache.pylibmc',
+                                  'oslo_cache.memcache_pool'):
+            conf_dict[f'{prefix}.arguments.memcached_expire_time'] = \
+                conf.cache.backend_expiration_time
+        elif conf.cache.backend in ('dogpile.cache.redis',
+                                    'dogpile.cache.redis_sentinel'):
+            conf_dict[f'{prefix}.arguments.redis_expiration_time'] = \
+                conf.cache.backend_expiration_time
+        else:
+            raise exception.ConfigurationError(
+                "Enabling backend expiration is not supported by"
+                "the %s driver", conf.cache.backend)
+
     if conf.cache.tls_enabled:
         if conf.cache.backend in ('dogpile.cache.bmemcache',
                                   'dogpile.cache.pymemcache',
